@@ -3,8 +3,8 @@
 use IO::File;
 use File::Stat::Moose;
 
-$fh = new IO::File '/etc/passwd';
-$st = new File::Stat::Moose file=>$fh;
+$fh = IO::File->new( $ARGV[0] || die "Usage: $0 filename\n" );
+$st = File::Stat::Moose->new( file=>$fh );
 
 print "Size: ", $st->size, "\n";    # named field
 print "Blocks: ". $st->[12], "\n";  # numbered field
